@@ -6,7 +6,7 @@ struct JsonType1 {
     name: String,
 }
 
-#[handler(method = "post")]
+#[handler]
 fn hello(Json(json1): Json<JsonType1>) -> String {
     format!(r#"{{"code": 0, "message": "{}"}}"#, json1.name)
 }
@@ -20,7 +20,8 @@ fn hello(Json(json1): Json<JsonType1>) -> String {
 // {"code": 1, "message": "missing field `name` at line 1 column 20"}
 #[tokio::main]
 async fn main() {
-    let app = route().at("/hello", hello).after(|mut resp| async move {
+    let mut app = route();
+    app.at("/hello").post(hello.after(|mut resp| async move {
         if !resp.status().is_success() {
             // returns the custom json error
             let reason = resp
@@ -35,7 +36,7 @@ async fn main() {
             .into_response());
         }
         Ok(resp)
-    });
+    }));
     let server = Server::bind("127.0.0.1:3000").await.unwrap();
     server.run(app).await.unwrap();
 }
