@@ -77,11 +77,11 @@ impl<'a, T: DeserializeOwned> FromRequest<'a> for Json<T> {
     }
 }
 
-impl<T: Serialize> IntoResponse for Json<T> {
+impl<T: Serialize + Send> IntoResponse for Json<T> {
     fn into_response(self) -> Response {
         let data = match serde_json::to_vec(&self.0) {
             Ok(data) => data,
-            Err(err) => return Error::bad_request(err).as_response(),
+            Err(err) => return Error::internal_server_error(err).as_response(),
         };
         Response::builder()
             .header(header::CONTENT_TYPE, "application/json")
